@@ -44,9 +44,6 @@
 #include <QWebEngineSettings>
 #include <kxmlguifactory.h>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include "akregratormigrateapplication.h"
-#endif
 #include "partadaptor.h"
 #include <QApplication>
 #include <QDomDocument>
@@ -55,10 +52,8 @@
 #include <QStringList>
 #include <QTextStream>
 #include <QTimer>
-#include <QWidget>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QWebEngineProfile>
-#endif
+#include <QWidget>
 
 #include <QFontDatabase>
 #include <QStandardPaths>
@@ -130,19 +125,10 @@ K_PLUGIN_FACTORY(AkregatorFactory, registerPlugin<Part>();)
 
 static Part *mySelf = nullptr;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
-    : KParts::Part(parent)
-#else
 Part::Part(QWidget *parentWidget, QObject *parent, const KPluginMetaData &data, const QVariantList &)
     : KParts::Part(parent, data)
-#endif
 {
     mySelf = this;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    AkregratorMigrateApplication migrate;
-    migrate.migrate();
-#endif
     // Make sure to initialize settings
     Part::config();
     initFonts();
@@ -367,9 +353,6 @@ bool Part::writeToTextFile(const QString &data, const QString &filename) const
         return false;
     }
     QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    stream.setCodec("UTF-8");
-#endif
     stream << data << Qt::endl;
     return file.commit();
 }
@@ -478,12 +461,12 @@ void Part::importFile(const QUrl &url)
         if (doc.setContent(file.readAll())) {
             m_mainWidget->importFeedList(doc);
         } else {
-            KMessageBox::error(m_mainWidget, i18n("Could not import the file %1 (no valid OPML)", filename), i18n("OPML Parsing Error"));
+            KMessageBox::error(m_mainWidget, i18n("Could not import the file %1 (no valid OPML)", filename), i18nc("@title:window", "OPML Parsing Error"));
         }
     } else {
         KMessageBox::error(m_mainWidget,
                            i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.", filename),
-                           i18n("Read Error"));
+                           i18nc("@title:window", "Read Error"));
     }
 }
 
@@ -493,7 +476,9 @@ void Part::exportFile(const QUrl &url)
         const QString fname = url.toLocalFile();
 
         if (!writeToTextFile(m_mainWidget->feedListToOPML().toString(), fname)) {
-            KMessageBox::error(m_mainWidget, i18n("Access denied: cannot write to file %1. Please check your permissions.", fname), i18n("Write Error"));
+            KMessageBox::error(m_mainWidget,
+                               i18n("Access denied: cannot write to file %1. Please check your permissions.", fname),
+                               i18nc("@title:window", "Write Error"));
         }
 
         return;
@@ -567,8 +552,7 @@ void Part::showOptions()
         if (TrayIcon::getInstance()) {
             connect(m_dialog, &KCMultiDialog::configCommitted, TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
-        const QVector<KPluginMetaData> availablePlugins =
-            KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/akregator"));
+        const QList<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim6/kcms/akregator"));
         for (const KPluginMetaData &metaData : availablePlugins) {
             m_dialog->addModule(metaData);
         }
@@ -604,10 +588,10 @@ void Part::initFonts()
 
     // TODO add CursiveFont, FantasyFont
 
-    KConfigGroup conf(Settings::self()->config(), "HTML Settings");
+    KConfigGroup conf(Settings::self()->config(), QStringLiteral("HTML Settings"));
 
     KConfig _konq(QStringLiteral("konquerorrc"), KConfig::NoGlobals);
-    KConfigGroup konq(&_konq, "HTML Settings");
+    KConfigGroup konq(&_konq, QStringLiteral("HTML Settings"));
 
     if (!conf.hasKey("MinimumFontSize")) {
         int minfs;
@@ -628,21 +612,12 @@ void Part::initFonts()
         }
         Settings::setMediumFontSize(medfs);
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
-    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
-    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
-    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
-    QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
-    QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
-#else
     QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
     QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
     QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
     QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
     QWebEngineProfile::defaultProfile()->settings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
     QWebEngineProfile::defaultProfile()->settings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
-#endif
 }
 
 bool Part::handleCommandLine(const QStringList &args)
@@ -690,7 +665,7 @@ void Part::clearCrashProperties()
         return;
     }
     KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup configGroup(&config, "Part");
+    KConfigGroup configGroup(&config, QStringLiteral("Part"));
     configGroup.writeEntry("crashed", false);
 }
 
@@ -700,7 +675,7 @@ void Part::saveCrashProperties()
         return;
     }
     KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup configGroup(&config, "Part");
+    KConfigGroup configGroup(&config, QStringLiteral("Part"));
     configGroup.deleteGroup();
 
     configGroup.writeEntry("crashed", true);
@@ -716,7 +691,7 @@ void Part::slotAutoSave()
 void Part::autoSaveProperties()
 {
     KConfig config(QStringLiteral("autosaved"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup configGroup(&config, "Part");
+    KConfigGroup configGroup(&config, QStringLiteral("Part"));
     configGroup.deleteGroup();
 
     saveProperties(configGroup);
@@ -730,7 +705,7 @@ void Part::autoReadProperties()
         return;
     }
     KConfig config(QStringLiteral("autosaved"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup configGroup(&config, "Part");
+    KConfigGroup configGroup(&config, QStringLiteral("Part"));
 
     readProperties(configGroup);
 }
@@ -740,7 +715,7 @@ void Part::slotRestoreSession(Akregator::CrashWidget::CrashAction type)
     switch (type) {
     case Akregator::CrashWidget::RestoreSession: {
         KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-        KConfigGroup configGroup(&config, "Part");
+        KConfigGroup configGroup(&config, QStringLiteral("Part"));
         readProperties(configGroup);
         clearCrashProperties();
         break;
@@ -755,3 +730,5 @@ void Part::slotRestoreSession(Akregator::CrashWidget::CrashAction type)
 }
 } // namespace Akregator
 #include "akregator_part.moc"
+
+#include "moc_akregator_part.cpp"
