@@ -122,18 +122,7 @@ ArticleViewerWebEngine::~ArticleViewerWebEngine() = default;
 
 void ArticleViewerWebEngine::printPreviewPage(QPrinter *printer)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     print(printer);
-#endif
-}
-
-void ArticleViewerWebEngine::execPrintPreviewPage(QPrinter *printer, int timeout)
-{
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (!mPageEngine->execPrintPreviewPage(printer, timeout)) {
-        qCWarning(AKREGATOR_LOG) << "Impossible to print page";
-    }
-#endif
 }
 
 void ArticleViewerWebEngine::updateSecurity()
@@ -385,7 +374,7 @@ void ArticleViewerWebEngine::disableIntroduction()
     KGuiItem noButton(i18n("Keep Enabled"));
     if (KMessageBox::questionTwoActions(this,
                                         i18n("Are you sure you want to disable this introduction page?"),
-                                        i18n("Disable Introduction Page"),
+                                        i18nc("@title:window", "Disable Introduction Page"),
                                         yesButton,
                                         noButton)
         == KMessageBox::PrimaryAction) {
@@ -421,7 +410,7 @@ bool ArticleViewerWebEngine::urlIsAMalwareButContinue()
     if (KMessageBox::SecondaryAction
         == KMessageBox::questionTwoActions(this,
                                            i18n("This web site is a malware, do you want to continue to show it?"),
-                                           i18n("Malware"),
+                                           i18nc("@title:window", "Malware"),
                                            KStandardGuiItem::cont(),
                                            KStandardGuiItem::cancel())) {
         return false;
@@ -433,10 +422,10 @@ void ArticleViewerWebEngine::slotCheckedUrlFinished(const QUrl &url, WebEngineVi
 {
     switch (status) {
     case WebEngineViewer::CheckPhishingUrlUtil::BrokenNetwork:
-        KMessageBox::error(this, i18n("The network is broken."), i18n("Check Phishing Url"));
+        KMessageBox::error(this, i18n("The network is broken."), i18nc("@title:window", "Check Phishing Url"));
         break;
     case WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl:
-        KMessageBox::error(this, i18n("The url %1 is not valid.", url.toString()), i18n("Check Phishing Url"));
+        KMessageBox::error(this, i18n("The url %1 is not valid.", url.toString()), i18nc("@title:window", "Check Phishing Url"));
         break;
     case WebEngineViewer::CheckPhishingUrlUtil::Ok:
         break;
@@ -550,3 +539,5 @@ void ArticleViewerWebEngine::slotActivatePlugin(MessageViewer::ViewerPluginInter
 }
 
 #include "articleviewerwebengine.moc"
+
+#include "moc_articleviewerwebengine.cpp"
