@@ -10,10 +10,9 @@
 #include "articleviewerwebengine.h"
 
 #include <QWidget>
-class QPrinter;
 class KActionCollection;
 
-namespace KPIMTextEdit
+namespace TextAddonsWidgets
 {
 class SlideContainer;
 }
@@ -53,19 +52,16 @@ private Q_SLOTS:
     void slotOpenInBrowser();
     void slotExportHtmlPageSuccess(const QString &filename);
     void slotExportHtmlPageFailed();
-    void slotHandlePagePrinted(bool result);
 
 private:
     void initializeActions(KActionCollection *ac);
     void initializeLayout(KActionCollection *ac);
-    void printRequested(QWebEnginePage *page);
     WebEngineViewer::FindBarWebEngineView *mFindBarWebView = nullptr;
     ArticleViewerWebEngine *mArticleViewerNg = nullptr;
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
     TextEditTextToSpeech::TextToSpeechContainerWidget *const mTextToSpeechWidget;
 #endif
-    KPIMTextEdit::SlideContainer *const mSliderContainer;
+    TextAddonsWidgets::SlideContainer *const mSliderContainer;
     WebEngineViewer::TrackingWarningWidget *const mTrackingWarningWidget;
-    QPrinter *mCurrentPrinter = nullptr;
 };
 }
