@@ -27,7 +27,7 @@ Akregator::AkregatorCentralWidget::~AkregatorCentralWidget() = default;
 bool AkregatorCentralWidget::previousSessionCrashed() const
 {
     KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup configGroup(&config, "Part");
+    KConfigGroup configGroup(&config, QStringLiteral("Part"));
 
     if (!configGroup.readEntry("crashed", false)) {
         return false;
@@ -54,3 +54,5 @@ void AkregatorCentralWidget::setMainWidget(Akregator::MainWidget *mainWidget)
         setCurrentWidget(mMainWidget);
     }
 }
+
+#include "moc_akregatorcentralwidget.cpp"
